@@ -2,7 +2,7 @@
 # housekeeping
 ########################################################################
 
-package LinkedList::Single v1.2.0;
+package LinkedList::Single v1.3.0;
 use v5.24;
 
 use Symbol;
@@ -383,7 +383,7 @@ sub set_meta
 sub add_meta
 {
     my $listh   = shift;
-    my $root    = $listh->root;
+    my $root    = $listh->root_node;
 
     push @$root, @_;
 
@@ -392,7 +392,8 @@ sub add_meta
 
 sub get_meta
 {
-    my $root    = $_[0]->root;
+    my $listh   = shift;
+    my $root    = $listh->root_node;
 
     wantarray
     ?   @{ $root }[ 1 .. $#$root ]
@@ -448,8 +449,6 @@ sub is_empty
 {
     # Q: does the current node have data?
     # A: it will if there is more than one element.
-    #
-    # $node is syntatic sugar, replacing "$#$$listh"
 
     my $listh   = shift;
     my $node    = $$listh;
@@ -460,14 +459,11 @@ sub is_empty
 sub clear_node_data
 {
     my $listh   = shift;
+    my $node    = $$listh;
 
-    # any data to replace the current data is
-    # left on the stack.
+    $#$node     = 0;
 
-    my $node    = $listh
-    or croak "Bogus node_data: listh handler '$listh' does not reference a node";
-
-    splice @$node, 1, $#$node
+    $listh
 }
 
 sub node_data
